@@ -927,7 +927,7 @@ def _sort_itemstrs(items, itemstrs, key=None):
     import ubelt as ub
     try:
         # Set ordering is not unique. Sort by strings values instead.
-        if _peek_isinstance(items, (set, frozenset)):
+        if len(items) > 0 and isinstance(items[0], (set, frozenset)):
             raise TypeError
         sortx = ub.argsort(items, key=key)
     except TypeError:
@@ -936,10 +936,6 @@ def _sort_itemstrs(items, itemstrs, key=None):
     return itemstrs
 
 
-def _peek_isinstance(items, types):
-    return len(items) > 0 and isinstance(items[0], types)
-
-
 def _rectify_countdown_or_bool(count_or_bool):
     """
     used by recursive functions to specify which level to turn a bool on in
